@@ -1,8 +1,10 @@
+from django.contrib.auth import get_user_model
+
 from microsoft_auth.models import MicrosoftAccount, XboxLiveAccount
 
 from . import TestCase
 
-USER_ID = 'test_user_id'
+USER_ID = "test_user_id"
 
 
 class ModelsTests(TestCase):
@@ -17,3 +19,10 @@ class ModelsTests(TestCase):
         a.save()
 
         self.assertEqual(USER_ID, str(a))
+
+    def test_username_with_spaces(self):
+        User = get_user_model()
+
+        u = User(username="Test username")
+        u.set_unusable_password()
+        u.full_clean()
